@@ -38,8 +38,8 @@ Q_PROPERTY(QString connectionTooltipIcon READ connectionTooltipIcon NOTIFY conne
 Q_PROPERTY(bool airplaneMode READ airplaneMode WRITE setAirplaneMode NOTIFY airplaneModeChanged)
 Q_OBJECT
 public:
-    explicit ConnectionIcon(QObject* parent = 0);
-    virtual ~ConnectionIcon();
+    explicit ConnectionIcon(QObject* parent = nullptr);
+    ~ConnectionIcon() override;
 
     bool connecting() const;
     QString connectionIcon() const;
